//
//  SITGeofence.h
//  SitumSDK
//
//  Created by Adrián Rodríguez on 16/07/2019.
//  Copyright © 2019 Situm. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "SITPoint.h"

/**
 * Class containing information about a geofence
 */
@interface SITGeofence : SITResource

/**
 * Name of the geofence
 */
@property (nonatomic, strong, nonnull, readonly) NSString* name;

/**
 * Code of the geofence
 */
@property (nonatomic, strong, nonnull, readonly) NSString* code;

/**
 * Description of the geofence
 */
@property (nonatomic, strong, nonnull, readonly) NSString* description  __attribute__((deprecated("Deprecated, use infoHtml instead")));

/**
 * Additional information of the geofence in html format
 */
@property (nonatomic, strong, nonnull, readonly) NSString* infoHtml;

/**
 * Id of the floor where the geofence is located
 */
@property (nonatomic, strong, nonnull, readonly) NSString* floorIdentifier;

/**
 * Id of the building where the geofence is located
 */
@property (nonatomic, strong, nonnull, readonly) NSString* buildingIdentifier;

/**
 * Array of SITPoints representing the corners of the geofence
 */
@property (nonatomic, strong, nonnull, readonly) NSArray<SITPoint*>* polygonPoints;

@end

/**
 * Class used to construct geofences
 */
@interface SITGeofenceBuilder: SITResource

/**
 * This method creates a geofence with the info provided
 *
 * @return An instance of the class geofence
 */
- (SITGeofence* _Nonnull) build;

/**
 * Adds a base geofence to the builder
 * @param geofence Instance of the class geofence
 *
 * @return Initialized builder
 */
- (instancetype _Nonnull) initWithGeofence: (SITGeofence* _Nonnull) geofence;

/**
 * Add name info to the builder
 * @param name Name info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) name: (NSString* _Nonnull) name;

/**
 * Add code info to the builder
 * @param Code info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) code: (NSString* _Nonnull) code;

/**
 * Add description info to the builder
 * @param Description info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) description: (NSString* _Nonnull) description;

/**
 * Add additional information in html format to the builder
 * @param infoHtml info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) infoHtml: (NSString* _Nonnull) infoHtml;

/**
 * Add floorId info to the builder
 * @param Floor Id info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) floorIdentifier: (NSString* _Nonnull) floorIdentifier;

/**
 * Add name buildingId to the builder
 * @param Building Id info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) buildingIdentifier: (NSString* _Nonnull) buildingIdentifier;

/**
 * Add points array to the builder
 * @param Points array to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) polygonPoints: (NSArray<SITPoint*>* _Nonnull) polygonPoints;

/**
 * Add identifier info to the builder
 * @param Identifier info to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) identifier: (NSString* _Nonnull) identifier;

/**
 * Add creation date info to the builder
 * @param Info about the creation date to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) createdAt: (NSDate* _Nonnull) createdAt;

/**
* Add update date info to the builder
* @param Info about the update date to be added to the builder
*
* @return The same instance of the builder upon which this method was called
*/
- (SITGeofenceBuilder* _Nonnull) updatedAt: (NSDate* _Nonnull) updatedAt;

/**
 * Add custom fields array to the builder
 * @param Custom fields array to be added to the builder
 *
 * @return The same instance of the builder upon which this method was called
 */
- (SITGeofenceBuilder* _Nonnull) customFields: (NSDictionary* _Nonnull) customFields;


// - (CLLocationCoordinate2D *)coordinates;

@end
